require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_filesystemaccessrule',
  dscmeta_resource_friendly_name: 'FileSystemAccessRule',
  dscmeta_resource_name: 'DSC_FileSystemAccessRule',
  dscmeta_module_name: 'FileSystemDsc',
  dscmeta_module_version: '1.1.1',
  docs: %q{
    The DSC FileSystemAccessRule resource type.
    Automatically generated from version 1.1.1
  },
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    ensure: {
      type:    'Enum[present, absent]',
      desc:    'Whether this resource should be present or absent on the target system.',
      default: 'present',
    },
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: "Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]",
      desc: %q{},

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: %q{
        Present to create the rule, Absent to remove an existing rule. Default value is 'Present'.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: "String",
      desc: %q{
        The path to the item that should have permissions set.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_identity: {
      type: "String",
      desc: %q{
        The identity to set permissions for.
      },
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_processonlyonactivenode: {
      type: "Optional[Boolean]",
      desc: %q{
        Specifies that the resource will only determine if a change is needed if the target node is the active host of the filesystem object. The user the configuration is run as must have permission to the Windows Server Failover Cluster.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_rights: {
      type: "Optional[Array[Enum['ListDirectory', 'ReadData', 'WriteData', 'CreateFiles', 'CreateDirectories', 'AppendData', 'ReadExtendedAttributes', 'WriteExtendedAttributes', 'Traverse', 'ExecuteFile', 'DeleteSubdirectoriesAndFiles', 'ReadAttributes', 'WriteAttributes', 'Write', 'Delete', 'ReadPermissions', 'Read', 'ReadAndExecute', 'Modify', 'ChangePermissions', 'TakeOwnership', 'Synchronize', 'FullControl']]]",
      desc: %q{
        The permissions to include in this rule. Optional if Ensure is set to value 'Absent'.
      },

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
